==> kleansweep_0.2.5.orig.tar.gz: kleansweep-0.2.5/src/main.cpp <==
/*
 * This file is a part of KleanSweep.
 *
 * Copyright (C) 2005 Pawel Stolowski <pawel.stolowski@wp.pl>
 *
 * KleanSweep is free software; you can redestribute it and/or modify it
 * under terms of GNU General Public License by Free Software Foundation.
 *
 * This program is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY. See GPL for more details.
 */

#include "sweeperwizard.h"
#include <kapplication.h>
#include <kaboutdata.h>
#include <kcmdlineargs.h>
#include <klocale.h>

static const char description[] =
    I18N_NOOP("Disk cleaning tool");

//static const char version[] = "0.1.9";

static KCmdLineOptions options[] =
{
//    { "+[URL]", I18N_NOOP( "Document to open" ), 0 },
    KCmdLineLastOption
};

int main(int argc, char **argv)
{
    KAboutData about("kleansweep", I18N_NOOP("KleanSweep"), VERSION, description,
                     KAboutData::License_GPL, "(C) 2005 Pawel Stolowski", 0, "http://linux.bydg.org/~yogin", "pawel.stolowski@wp.pl");
    about.addAuthor( "Pawel Stolowski", 0, "pawel.stolowski@wp.pl" );
    KCmdLineArgs::init(argc, argv, &about);
    KCmdLineArgs::addCmdLineOptions( options );
    KApplication app;
    SweeperWizard *mainWin = 0;
    
    if (app.isRestored())
    {
        //RESTORE(KleanSweep);
    }
    else
    {
        // no session.. just start up normally
        KCmdLineArgs *args = KCmdLineArgs::parsedArgs();

        /// @todo do something with the command line args here

        mainWin = new SweeperWizard(NULL);
        
        app.setMainWidget( mainWin );
        mainWin->show();

        args->clear();
    }

    // mainWin has WDestructiveClose flag by default, so it will delete itself.
    return app.exec();
}

==> kleansweep_0.2.9.orig.tar.gz: kleansweep-0.2.9.orig/src/main.cpp <==
/*
 * This file is a part of KleanSweep.
 *
 * Copyright (C) 2005 Pawel Stolowski <pawel.stolowski@wp.pl>
 *
 * KleanSweep is free software; you can redestribute it and/or modify it
 * under terms of GNU General Public License by Free Software Foundation.
 *
 * This program is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY. See GPL for more details.
 */

#include "sweeperwizard.h"
#include <kapplication.h>
#include <kaboutdata.h>
#include <kcmdlineargs.h>
#include <klocale.h>

static const char description[] =
    I18N_NOOP("Disk cleaning tool");

//static const char version[] = "0.1.9";

static KCmdLineOptions options[] =
{
//    { "+[URL]", I18N_NOOP( "Document to open" ), 0 },
    KCmdLineLastOption
};

int main(int argc, char **argv)
{
    KAboutData about("kleansweep", I18N_NOOP("KleanSweep"), VERSION, description,
                     KAboutData::License_GPL, "(C) 2005 Pawel Stolowski", 0, "http://linux.bydg.org/~yogin", "pawel.stolowski@wp.pl");
    about.addAuthor( "Pawel Stolowski", 0, "pawel.stolowski@wp.pl" );
    about.setTranslator(I18N_NOOP("_: NAME OF TRANSLATORS\\nYour names"), I18N_NOOP("_: EMAIL OF TRANSLATORS\\nYour emails"));
    KCmdLineArgs::init(argc, argv, &about);
    KCmdLineArgs::addCmdLineOptions( options );
    KApplication app;
    SweeperWizard *mainWin = 0;
    
    if (app.isRestored())
    {
        //RESTORE(KleanSweep);
    }
    else
    {
        // no session.. just start up normally
        KCmdLineArgs *args = KCmdLineArgs::parsedArgs();

        /// @todo do something with the command line args here

        mainWin = new SweeperWizard(NULL);
        
        app.setMainWidget( mainWin );
        mainWin->show();

        args->clear();
    }

    // mainWin has WDestructiveClose flag by default, so it will delete itself.
    return app.exec();
}
